@@ -1,5 +1,6 @@
 import os
 import warnings
+from nctoolkit.session import nc_safe
 
 
 def append(self, x=None):
@@ -12,8 +13,10 @@ def append(self, x=None):
      File path(s) to add to the dataset
     """
 
-    # run any commands, as it makes no sense to add files while commands are waiting to run
+    # run, as it makes no sense to add files while commands are waiting to run
     self.run()
+    if "api.DataSet" in str(type(x)):
+        x.run()
 
     if x is None:
         raise TypeError("Please supply files")
@@ -48,4 +51,6 @@ def append(self, x=None):
         if type(self.current) is str:
             self.current = [self.current, ff]
         else:
+            nc_safe.append(ff)
             self.current.append(ff)
+
