@@ -2,20 +2,25 @@ from datetime import datetime
 import xarray as xr
 
 
-def to_xarray(self, decode_times=True):
+def to_xarray(self, decode_times=True, cdo_times=False):
     """
     Open a dataset as an xarray object
 
     Parameters
     -------------
     decode_times: boolean
-        Set to False if you do not want xarray to decode the times. Default is True. If xarray cannot decode times, CDO will be used.
+        Set to False if you do not want xarray to decode the times. Default is True.
+        If xarray cannot decode times, CDO will be used.
+    cdo_times: boolean
+        Set to True if you do not want CDO to decode the times
 
     """
     # 3 possibilities:
     #   1: decode_times is False - just open in xarray
-    #   2: decode_times is True, and xarray can decodes times - just open in xarray
-    #   3: decode_times is True, but xarray cannot decodes times - open in xarray, then use cdo to get the times
+    #   2: decode_times is True, and xarray can decodes times -
+    #   just open in xarray
+    #   3: decode_times is True, but xarray cannot decodes times - open in xarray,
+    #   then use cdo to get the times
 
     # All commands need to be run before opening it xarray
     self.run()
@@ -29,16 +34,17 @@ def to_xarray(self, decode_times=True):
         return data
 
     # decoding times is trickier, because xarray may fail to do this
-    # start by asssuming we don't need to use cdo to work out the times, and figure out if that works
-    cdo_times = False
+    # start by asssuming we don't need to use cdo to work out the times,
+    # and figure out if that works
 
-    try:
-        if type(self.current) is str:
-            test = xr.open_dataset(self.current, decode_times=decode_times)
-        else:
-            test = xr.open_mfdataset(self.current, decode_times=decode_times)
-    except:
-        cdo_times = True
+    if cdo_times is False:
+        try:
+            if type(self.current) is str:
+                test = xr.open_dataset(self.current, decode_times=decode_times)
+            else:
+                test = xr.open_mfdataset(self.current, decode_times=decode_times)
+        except Exception as e:
+            cdo_times = True
 
     # if it does, then just open the data in xarray
 
@@ -49,7 +55,8 @@ def to_xarray(self, decode_times=True):
             data = xr.open_mfdataset(self.current, decode_times=decode_times)
         return data
 
-    # If it does not, then we use cdo to pull out the times, then push those to the xarray object
+    # If it does not, then we use cdo to pull out the times,
+    # then push those to the xarray object
 
     if type(self.current) is str:
 
@@ -67,16 +74,19 @@ def to_xarray(self, decode_times=True):
         return data
 
 
-def to_dataframe(self, decode_times=True):
+def to_dataframe(self, decode_times=True, cdo_times=False):
     """
     Open a dataset as a pandas data frame
 
     Parameters
     -------------
     decode_times: boolean
-        Set to False if you do not want xarray to decode the times prior to conversion to data frame. Default is True.
+        Set to False if you do not want xarray to decode the times prior to
+        conversion to data frame. Default is True.
+    cdo_times: boolean
+        Set to True if you do not want CDO to decode the times
 
     """
     # everything must be run first
     self.run()
-    return self.to_xarray(decode_times=decode_times).to_dataframe()
+    return self.to_xarray(decode_times=decode_times, cdo_times=cdo_times).to_dataframe()
